# BuyerUpdate

A request to update a buyer.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**billing_details** | **object, none_type** | The optional billing details to update a buyer. | [optional] 
**external_identifier** | **str, none_type** | An external identifier that can be used to match the buyer against your own records. This value needs to be unique for all buyers. | [optional] 
**display_name** | **str, none_type** | A unique name for this buyer which is used in the Gr4vy admin panel to give a buyer a human readable name. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


